@@ -5,16 +5,17 @@
 (autoload 'custom-add-loads "cus-load")
 
 (custom-add-loads 'filladapt '("filladapt"))
-(custom-add-loads 'apache '("auto-autoloads" "apache-mode"))
+(custom-add-loads 'apache '("apache-mode" "auto-autoloads"))
 (custom-add-loads 'rtf '("rtf-support"))
 (custom-add-loads 'convenience '("whitespace"))
 (custom-add-loads 'xrdb '("xrdb-mode"))
 (custom-add-loads 'ispell '("flyspell"))
 (custom-add-loads 'tools '("autoinsert" "folding"))
+(custom-add-loads 'whitespace-visual '("whitespace-visual-mode"))
 (custom-add-loads 'hypermedia '("css-mode" "htmlize"))
 (custom-add-loads 'desktop-entry '("desktop-entry-mode"))
 (custom-add-loads 'css '("css-mode"))
-(custom-add-loads 'outlines '("whitespace-mode"))
+(custom-add-loads 'outlines '("whitespace-mode" "whitespace-visual-mode"))
 (custom-add-loads 'hexl '("hexl"))
 (custom-add-loads 'old-whitespace '("whitespace-mode"))
 (custom-add-loads 'data '("hexl"))
@@ -35,7 +36,7 @@
 (custom-add-loads 'whitespace-faces '("whitespace"))
 (custom-add-loads 'whitespace '("whitespace"))
 (custom-add-loads 'editing '("whitespace"))
-(custom-add-loads 'matching '("whitespace-mode"))
+(custom-add-loads 'matching '("whitespace-mode" "whitespace-visual-mode"))
 (custom-add-loads 'winmgr '("winmgr-mode"))
 (custom-add-loads 'i18n '("po-mode"))
 
